package com.example.zxweb.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.zxweb.common.api.vo.Result;
import com.example.zxweb.entity.ZxCelue;
import com.example.zxweb.service.IZxCelueService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * @Description 策略管理接口
 * @Author ZhouWenTao
 * @Date 2023/9/13 11:50
 */
@Api(tags = "策略管理")
@RequestMapping("/celue")
@RestController
public class CelueController {
    @Resource
    IZxCelueService zxCelueService;

    @ApiOperation(value = "策略列表")
    @GetMapping(value = "/list")
    public Result<?> list(@RequestParam(value = "page",defaultValue = "1")Integer page,@RequestParam(value = "limit",defaultValue = "10")Integer limit,
                          @RequestParam(value = "name",defaultValue = "")String name,@RequestParam(value = "status",defaultValue = "")String status){
        LambdaQueryWrapper<ZxCelue> queryWrapper=new LambdaQueryWrapper<>();
        if (StringUtils.isNotBlank(name)) {
            queryWrapper.like(ZxCelue::getName,name);
        }
        if (StringUtils.isNotBlank(status)) {
            queryWrapper.eq(ZxCelue::getStatus,status);
        }
        Page<ZxCelue> pageList = zxCelueService.page(new Page<>(page, limit),queryWrapper);
        return Result.OK(pageList);
    }

    @ApiOperation(value = "策略列表-全部")
    @GetMapping(value = "/listAll")
    public Result<?> listAll(){
        return Result.OK(zxCelueService.list());
    }

    @ApiOperation(value = "详情")
    @GetMapping
    public Result<?> getDetail(@RequestParam String id){
        return Result.OK(zxCelueService.getById(id));
    }

    @ApiOperation(value = "新增")
    @PostMapping
    public Result<?>add(@RequestBody ZxCelue zxCelue){
        zxCelueService.save(zxCelue);
        return Result.OK();
    }

    @ApiOperation(value = "编辑")
    @PutMapping
    public Result<?>edit(@RequestBody ZxCelue zxCelue){
        zxCelueService.updateById(zxCelue);
        return Result.OK();
    }

    @ApiOperation(value = "编辑")
    @PutMapping("/status")
    public Result<?>status(@RequestBody ZxCelue zxCelue){
        ZxCelue celue = zxCelueService.getById(zxCelue.getCelueid());
        LambdaUpdateWrapper<ZxCelue> updateWrapper=new LambdaUpdateWrapper<>();
        updateWrapper.eq(ZxCelue::getCelueid,celue.getCelueid());
        if ("0".equals(celue.getStatus())) {
            updateWrapper.set(ZxCelue::getStatus,"1");
        }else{
            updateWrapper.set(ZxCelue::getStatus,"0");
        }
        zxCelueService.update(updateWrapper);
        return Result.OK();
    }
    /**
     * 删除
     */
    @ApiOperation(value="删除", notes="删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name="id") String id) {
        zxCelueService.removeById(id);
        return Result.OK();
    }

}
